==> cosmo_1.0.tar.gz: cosmo/src/INCLUDE/lstarts.h <==
int getSvLogLR(
		DATASET *dataSet   /* the dataset */
		);


int initSvLogLR(
		 DATASET *dataSet   /* the dataset */
		 );

int seq2pwm(
	     double *pwm,   /* on exit: the PWM */
	     int *seq,      /* the oligo sequence */
	     int width,     /* width of oligo */
	     double hiProb  /* probability to assign to observed nucleotide */
	     );

int addCol2pwm(
		double *pwm,   /* the PWM to which we are adding a column */
		int *seq,      /* the sequence from which the PWM was constructed */
		int start,     /* the starting position of the corresponding oligo */
		int newWidth,  /* the new width of the PWM */
		double hiProb  /* the probability to assign to observed nucleotides */
		);

int printMProbs(
		 DATASET *dataSet,   /* the dataset */
		 int width,          /* width of motif */
		 int spaceNum        /* are motif probs stored in mProbs1 or mProbs2? */
		 );

int getNewMProbs(
		  DATASET *dataSet,    /* the dataset */
		  double *pwm,         /* PWM for which to calculate motif probabilities */ 
		  int width,           /* width of this PWM */
		  int spaceNum,        /* store mProbs in intMotProbs1 or intMotProbs2 ? */
		  BOOLEAN excludeAny,  /* are any sequences to be excluded for CV purposes? */
		  int *excludeCv       /* array indicating which sequences are to be exclude, NULL if none are to be excluded */
		  );

int getHigherMProbs(
		     DATASET *dataSet,    /* the dataset */
		     double *pwm,         /* PWM for which motif probabilities are desired */
		     int width,           /* widht of this PWM */
		     int spaceNum         /* are motif probs for width-1 stored in intMotProbs1 or intMotProbs2 ? */
		     );

int getOverMProbs(

		   DATASET *dataSet,  /* the dataset */
		   double *pwm,       /* the PWM for which to find the motif probabilities */
		   double *prevPwm,   /* the PWM for width+1 starting in the previous position */
		   int width,         /* the width of the current PWM */
		   int spaceNum,      /* store mProbs in mProbs1 or mProbs2 ? */
		   BOOLEAN oneWidth   /* is there only one candidate width? */
		   );

int evalModLiks(
		 DATASET *dataSet,      /* the dataset */
		 int width,             /* motif width */
		 int oligoSeqNum,       /* sequence from oligo was derived */
		 int oligoStart,        /* position in sequence at which oligo starts */
		 int spaceNum           /* are motif probs stored in mProbs1 or mProbs2? */
		 );

int copyMProbs(
		DATASET *dataSet,    /* the dataset */
		int fromSpace,       /* copy from this space */
		int toSpace          /* to this space */
		);

int xLikStarts(
		DATASET *dataSet  /* dataset */
		);

==> cosmo_1.6.0.tar.gz: cosmo/src/INCLUDE/lstarts.h <==
int getSvLogLR(
		DATASET *dataSet   /* the dataset */
		);


int initSvLogLR(
		 DATASET *dataSet   /* the dataset */
		 );

int seq2pwm(
	     double *pwm,   /* on exit: the PWM */
	     int *seq,      /* the oligo sequence */
	     int width,     /* width of oligo */
	     double hiProb  /* probability to assign to observed nucleotide */
	     );

int addCol2pwm(
		double *pwm,   /* the PWM to which we are adding a column */
		int *seq,      /* the sequence from which the PWM was constructed */
		int start,     /* the starting position of the corresponding oligo */
		int newWidth,  /* the new width of the PWM */
		double hiProb  /* the probability to assign to observed nucleotides */
		);

int printMProbs(
		 DATASET *dataSet,   /* the dataset */
		 int width,          /* width of motif */
		 int spaceNum        /* are motif probs stored in mProbs1 or mProbs2? */
		 );

int getNewMProbs(
		  DATASET *dataSet,    /* the dataset */
		  double *pwm,         /* PWM for which to calculate motif probabilities */ 
		  int width,           /* width of this PWM */
		  int spaceNum         /* store mProbs in intMotProbs1 or intMotProbs2 ? */
		  );

int getHigherMProbs(
		     DATASET *dataSet,    /* the dataset */
		     double *pwm,         /* PWM for which motif probabilities are desired */
		     int width,           /* widht of this PWM */
		     int spaceNum         /* are motif probs for width-1 stored in intMotProbs1 or intMotProbs2 ? */
		     );

int getOverMProbs(

		   DATASET *dataSet,  /* the dataset */
		   double *pwm,       /* the PWM for which to find the motif probabilities */
		   double *prevPwm,   /* the PWM for width+1 starting in the previous position */
		   int width,         /* the width of the current PWM */
		   int spaceNum,      /* store mProbs in mProbs1 or mProbs2 ? */
		   BOOLEAN oneWidth   /* is there only one candidate width? */
		   );

int evalModLiks(
		 DATASET *dataSet,      /* the dataset */
		 int width,             /* motif width */
		 int oligoSeqNum,       /* sequence from oligo was derived */
		 int oligoStart,        /* position in sequence at which oligo starts */
		 int spaceNum           /* are motif probs stored in mProbs1 or mProbs2? */
		 );

int copyMProbs(
		DATASET *dataSet,    /* the dataset */
		int fromSpace,       /* copy from this space */
		int toSpace          /* to this space */
		);

int xLikStarts(
		DATASET *dataSet  /* dataset */
		);
